@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2010 Ixonos Plc.
- * Copyright (C) 2011-2017 Philipp Spitzer, gregor herrmann, Stefan Stahl
+ * Copyright (C) 2011-2021 Philipp Spitzer, gregor herrmann, Stefan Stahl
  *
  * This file is part of ConfClerk.
  *
@@ -21,18 +21,26 @@
 #define APPLICATION_H
 
 #include <QApplication>
+#include "conference.h"
 
 class Application : public QApplication
 {
     Q_OBJECT
 
 public:
-    Application(int& argc, char** argv)
-    : QApplication(argc, argv)
-    { }
-    virtual ~Application() { }
+    Application(int& argc, char** argv): QApplication(argc, argv) {}
+    virtual ~Application() {}
 
     virtual bool notify(QObject* receiver, QEvent* event);
+
+    void setActiveConference(Conference& conference) {mActiveConference = conference; mHasActiveConference = true;}
+    void unsetActiveConference() {mHasActiveConference = false;}
+    Conference& activeConference() {return mActiveConference;}
+    bool hasActiveConference() const {return mHasActiveConference;}
+
+private:
+    bool mHasActiveConference = false;
+    Conference mActiveConference;
 };
 
 #endif
