@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2010 Ixonos Plc.
- * Copyright (C) 2011-2017 Philipp Spitzer, gregor herrmann, Stefan Stahl
+ * Copyright (C) 2011-2021 Philipp Spitzer, gregor herrmann, Stefan Stahl
  *
  * This file is part of ConfClerk.
  *
@@ -26,6 +26,7 @@ DayViewTabContainer::DayViewTabContainer(QWidget *aParent): TabContainer(aParent
 
 void DayViewTabContainer::expandTimeGroup(QTime time, int conferenceId) {
     EventModel* eventModel = static_cast<EventModel*>(treeView->model());
+    Conference conference = Conference::getById(conferenceId);
 
     // iterate over the time groups
     for (int g = 0; g != eventModel->rowCount(); ++g) {
@@ -35,7 +36,9 @@ void DayViewTabContainer::expandTimeGroup(QTime time, int conferenceId) {
             QModelIndex eventIdx = eventModel->index(e, 0, groupIdx);
             int eventId = eventIdx.data().toInt();
             Event event = Event::getById(eventId, conferenceId);
-            if (time < event.start().time().addSecs(event.duration())) { // if time < end
+            QDateTime eventStart = event.start();
+            if (conference.hasDisplayTimeShift()) eventStart = eventStart.addSecs(conference.displayTimeShift() * 60);
+            if (time < eventStart.time().addSecs(event.duration())) { // if time < end
                 // expand this group
                 treeView->expand(groupIdx);
                 treeView->scrollTo(eventIdx, QAbstractItemView::PositionAtTop);
