@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2010 Ixonos Plc.
- * Copyright (C) 2011-2017 Philipp Spitzer, gregor herrmann, Stefan Stahl
+ * Copyright (C) 2011-2021 Philipp Spitzer, gregor herrmann, Stefan Stahl
  *
  * This file is part of ConfClerk.
  *
@@ -30,6 +30,8 @@ QSqlRecord const Conference::sColumns = Conference::toRecord(QList<QSqlField>()
     << QSqlField("end", QVariant::DateTime)
     << QSqlField("day_change", QVariant::Int)
     << QSqlField("timeslot_duration", QVariant::Int)
+    << QSqlField("utc_offset", QVariant::Int)
+    << QSqlField("display_time_shift", QVariant::Int)
     << QSqlField("active", QVariant::Bool)
     << QSqlField("url", QVariant::String)
     );
@@ -58,3 +60,6 @@ int Conference::activeConference() {
 }
 
 
+QTime Conference::shiftTime(const QTime& value) const {
+    return value.addSecs(displayTimeShift() * 60);
+}
