@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2010 Ixonos Plc.
- * Copyright (C) 2011-2017 Philipp Spitzer, gregor herrmann, Stefan Stahl
+ * Copyright (C) 2011-2021 Philipp Spitzer, gregor herrmann, Stefan Stahl
  *
  * This file is part of ConfClerk.
  *
@@ -29,7 +29,8 @@
 
 It also provides typed access to the conferences from ConferenceEditor.
 
-It does not actually modify anything in DB, this is performed by other classes.
+It does not actually modify anything in DB (unless methods changing the conference instance returned by conferenceFromIndex are used),
+this is performed by other classes.
 
 \see ConferenceEditor, MainWindow::showConferences()
 */
@@ -43,6 +44,7 @@ public:
     virtual QVariant data(const QModelIndex& index, int role = Qt::DisplayRole) const;
 
     const Conference& conferenceFromIndex(const QModelIndex&) const;
+    Conference& conferenceFromIndex(const QModelIndex&);
     QModelIndex indexFromId(int id) const;
 public slots:
     void newConferenceBegin();
