@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2010 Ixonos Plc.
- * Copyright (C) 2011-2017 Philipp Spitzer, gregor herrmann, Stefan Stahl
+ * Copyright (C) 2011-2021 Philipp Spitzer, gregor herrmann, Stefan Stahl
  *
  * This file is part of ConfClerk.
  *
@@ -17,16 +17,16 @@
  * You should have received a copy of the GNU General Public License along with
  * ConfClerk.  If not, see <http://www.gnu.org/licenses/>.
  */
-#include "delegate.h"
-#include "eventmodel.h"
-#include "track.h"
-
 #include <QDebug>
 #include <QPainter>
 
+#include "delegate.h"
+#include "eventmodel.h"
+#include "track.h"
+#include "conference.h"
 #include "room.h"
+#include "application.h"
 
-const int RADIUS = 10;
 const int SPACER = 10;
 
 const double scaleFactor1 = 0.4;
@@ -88,6 +88,7 @@ void Delegate::paint(QPainter *painter, const QStyleOptionViewItem &option, cons
         fontSmall.setBold(false);
         fontSmall.setPixelSize(aux*0.2);
         QFontMetrics fmSmall(fontSmall);
+
         // font SMALL bold
         QFont fontSmallB = fontSmall;
         fontSmallB.setBold(true);
@@ -148,12 +149,13 @@ void Delegate::paint(QPainter *painter, const QStyleOptionViewItem &option, cons
         painter->setPen(QPen(conflictSeverity != csNone ? Qt::black : textColor));
         QPointF titlePointF(option.rect.x() + SPACER,
                             option.rect.y() + SPACER + mControls[FavouriteControlStrong]->image()->height());
-        QTime start = event->start().time();
+        Conference& conference = ((Application*) qApp)->activeConference();
+        QTime start = conference.shiftTime(event->start().time());
         painter->setFont(fontBig);
-        painter->drawText(titlePointF,start.toString("hh:mm") + "-" + start.addSecs(event->duration()).toString("hh:mm") + ", " + event->roomName());
+        painter->drawText(titlePointF, start.toString("hh:mm") + "-" + start.addSecs(event->duration()).toString("hh:mm") + ", " + event->roomName());
 
         // title
-        titlePointF.setY(titlePointF.y()+fmBig.height()-fmBig.descent());
+        titlePointF.setY(titlePointF.y() + fmBig.lineSpacing());
         painter->setFont(fontBigB);
         QString title = event->title();
         if(fmBigB.boundingRect(title).width() > (option.rect.width()-2*SPACER)) // the title won't fit the screen
@@ -170,22 +172,22 @@ void Delegate::paint(QPainter *painter, const QStyleOptionViewItem &option, cons
             }
             title += "...";
         }
-        painter->drawText(titlePointF,title);
+        painter->drawText(titlePointF, title);
 
         // persons
-        titlePointF.setY(titlePointF.y()+fmSmall.height()-fmSmall.descent());
+        titlePointF.setY(titlePointF.y() + fmBigB.descent() + fmSmall.lineSpacing());
         painter->setFont(fontSmall);
         QString presenterPrefix = event->persons().count() < 2 ? "Presenter" : "Presenters";
-        painter->drawText(titlePointF,presenterPrefix + ": " + event->persons().join(" and "));
+        painter->drawText(titlePointF, presenterPrefix + ": " + event->persons().join(" and "));
 
         // track
-        titlePointF.setY(titlePointF.y()+fmSmall.height()-fmSmall.descent());
-        painter->drawText(titlePointF,"Track: " + Track::retrieveTrackName(event->trackId()));
+        titlePointF.setY(titlePointF.y() + fmSmall.lineSpacing());
+        painter->drawText(titlePointF, "Track: " + Track::retrieveTrackName(event->trackId()));
     }
 
     else // doesn't have parent - time-groups' elements (top items)
     {
-        int numFav = numberOfFavourities(index);
+        int numFav = numberOfFavourites(index);
         int numAlarm = numberOfAlarms(index);
 
         QStyleOptionButton styleOptionButton;
@@ -356,14 +358,14 @@ bool Delegate::isPointFromRect(const QPoint &aPoint, const QRect &aRect) const
     return false;
 }
 
-int Delegate::numberOfFavourities(const QModelIndex &index) const
+int Delegate::numberOfFavourites(const QModelIndex &index) const
 {
     if(index.parent().isValid()) // it's event, not time-group
         return 0;
 
     int nrofFavs = 0;
     for(int i=0; i<index.model()->rowCount(index); i++)
-        if(static_cast<Event*>(index.child(i,0).internalPointer())->favourite() != Favourite_no)
+        if(static_cast<Event*>(index.model()->index(i, 0, index).internalPointer())->favourite() != Favourite_no)
             nrofFavs++;
 
     return nrofFavs;
@@ -376,7 +378,7 @@ int Delegate::numberOfAlarms(const QModelIndex &index) const
 
     int nrofAlarms = 0;
     for(int i=0; i<index.model()->rowCount(index); i++)
-        if(static_cast<Event*>(index.child(i,0).internalPointer())->hasAlarm())
+        if(static_cast<Event*>(index.model()->index(i, 0, index).internalPointer())->hasAlarm())
             nrofAlarms++;
 
     return nrofAlarms;
