@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2010 Ixonos Plc.
- * Copyright (C) 2011-2017 Philipp Spitzer, gregor herrmann, Stefan Stahl
+ * Copyright (C) 2011-2021 Philipp Spitzer, gregor herrmann, Stefan Stahl
  *
  * This file is part of ConfClerk.
  *
@@ -90,10 +90,10 @@ class Delegate : public QItemDelegate
         void defineControls();
         // TODO: the better place for these methods would be 'eventmodel'
         // they are used in 'paint' method and so it's better to obtain number of
-        // favourities/alarms once when the data has changed and not to call
+        // favourites/alarms once when the data has changed and not to call
         // these methods which iterate over all Events in corresponding group
         // every time it requires them
-        int numberOfFavourities(const QModelIndex &index) const;
+        int numberOfFavourites(const QModelIndex &index) const;
         int numberOfAlarms(const QModelIndex &index) const;
 
     private:
