@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2010 Ixonos Plc.
- * Copyright (C) 2011-2017 Philipp Spitzer, gregor herrmann, Stefan Stahl
+ * Copyright (C) 2011-2021 Philipp Spitzer, gregor herrmann, Stefan Stahl
  *
  * This file is part of ConfClerk.
  *
@@ -103,10 +103,19 @@ QList<Event> Event::conflictEvents(int aEventId, int conferenceId) {
 
 
 QList<Event> Event::getImminentAlarmEvents(int maxSecToAlarm, int conferenceId) {
+    Conference conference = Conference::getById(conferenceId);
     QSqlQuery query;
     query.prepare(selectQuery() + "WHERE xid_conference = :conf AND (start < :start AND alarm = 1) ORDER BY start, duration");
     query.bindValue(":conf", conferenceId);
-    query.bindValue(":start", convertToDb(QDateTime::currentDateTime().addSecs(maxSecToAlarm), QVariant::DateTime));
+    QDateTime start;
+    if (conference.hasUtcOffset()) {
+        start = QDateTime::currentDateTimeUtc().addSecs(conference.utcOffset() * 60);
+    } else {
+        start = QDateTime::currentDateTime();
+        if (conference.hasDisplayTimeShift()) start = start.addSecs(conference.displayTimeShift() * 60);
+    }
+    start = start.addSecs(maxSecToAlarm);
+    query.bindValue(":start", convertToDb(start, QVariant::DateTime));
     return load(query);
 }
 
