@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2010 Ixonos Plc.
- * Copyright (C) 2011-2017 Philipp Spitzer, gregor herrmann, Stefan Stahl
+ * Copyright (C) 2011-2021 Philipp Spitzer, gregor herrmann, Stefan Stahl
  *
  * This file is part of ConfClerk.
  *
@@ -66,10 +66,10 @@ void ScheduleXmlParser::parseDataImpl(const QByteArray &aData, const QString& ur
     {
         QDomElement conferenceElement = scheduleElement.firstChildElement("conference");
         QTime conference_day_change;
+        QHash<QString,QString> conference;
         if (!conferenceElement.isNull())
         {
             emit(parsingScheduleBegin());
-            QHash<QString,QString> conference;
             conference["id"] = QString::number(conferenceId); // conference ID is assigned automatically if 0
             conference["title"] = conferenceElement.firstChildElement("title").text();
             conference["subtitle"] = conferenceElement.firstChildElement("subtitle").text();
@@ -81,8 +81,10 @@ void ScheduleXmlParser::parseDataImpl(const QByteArray &aData, const QString& ur
             if (conferenceDayChangeStr.isEmpty()) conferenceDayChangeStr = "04:00:00";
             conference["day_change"] = conferenceDayChangeStr;
             conference["timeslot_duration"] = conferenceElement.firstChildElement("timeslot_duration").text(); // time
+            conference["utc_offset"] = QString();
+            conference["display_time_shift"] = QString();
             conference["url"] = url;
-            sqlEngine->addConferenceToDB(conference, conferenceId);
+            sqlEngine->addConferenceToDB(conference, conferenceId, conferenceId != 0);
             conferenceId = conference["id"].toInt();
             conference_title = conference["title"];
             conference_day_change = QTime(0, 0).addSecs(conference["day_change"].toInt());
@@ -133,9 +135,16 @@ void ScheduleXmlParser::parseDataImpl(const QByteArray &aData, const QString& ur
                         QDomElement eventDateElement = eventElement.firstChildElement("date");
                         if (!eventDateElement.isNull()) {
                             QString date_str = eventDateElement.text(); // date eg. 2009-02-07T10:00:00+00:00
-                            event_date = QDate::fromString(date_str.left(sqlEngine->DATE_FORMAT.size()), sqlEngine->DATE_FORMAT);
+                            QDateTime event_date_time = QDateTime::fromString(date_str, Qt::ISODate);
+                            if (conference.value("utc_offset").isEmpty()) {
+                                QDateTime utc_event_date_time = event_date_time;
+                                utc_event_date_time.setTimeSpec(Qt::UTC);
+                                int conference_utc_offset = event_date_time.secsTo(utc_event_date_time);
+                                conference["utc_offset"] = QString::number(conference_utc_offset);
+                            }
+                            event_date = event_date_time.date();
                         } else {
-                            event_date = QDate::fromString(dayElement.attribute("date"),sqlEngine->DATE_FORMAT); // date eg. 2009-02-07
+                            event_date = QDate::fromString(dayElement.attribute("date"), Qt::ISODate); // date eg. 2009-02-07
                             if (event_start < conference_day_change) event_date = event_date.addDays(1);
                         }
                         event["date"] = event_date.toString(sqlEngine->DATE_FORMAT); // date eg. 2009-02-07
@@ -180,6 +189,12 @@ void ScheduleXmlParser::parseDataImpl(const QByteArray &aData, const QString& ur
                 }
             } // parsing room elements
         } // parsing day elements
+
+        // Re-write conference as utc_offset was not known previously
+        if (!conference.value("utc_offset").isEmpty()) {
+            sqlEngine->addConferenceToDB(conference, conferenceId, conferenceId != 0);
+        }
+
     } // schedule element
     if (conference_title.isNull()) throw ParseException("Could not parse schedule");
 
